==> option-annotations-2.0.0-sources.jar: io/dekorate/option/adapter/VcsConfigAdapter.java <==
package io.dekorate.option.adapter;

import java.nio.file.Path;
import io.dekorate.option.config.VcsConfig;
import java.lang.String;
import io.dekorate.option.config.VcsConfigBuilder;
import java.util.Comparator;
import io.dekorate.option.annotation.VcsOptions;
import io.dekorate.project.Project;
import io.dekorate.project.BuildInfo;
import java.lang.Object;
import java.util.List;
import io.dekorate.project.ScmInfo;
import java.util.Map;

public class VcsConfigAdapter {


    public static VcsConfig adapt(VcsOptions instance) {
        return newBuilder(instance).build();
    }

    public static VcsConfigBuilder newBuilder(VcsOptions instance) {
        return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(null,
                    null,
                    instance.remote(),
                    instance.httpsPreferred()));
    }

    public static VcsConfig adapt(Map map) {
        return new io.dekorate.option.config.VcsConfig(
        null,
        null,
                       (String)(map instanceof Map ? ((Map)map).getOrDefault("remote", "origin") : "origin"),
                       Boolean.parseBoolean(String.valueOf(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred","false") : "false")));
    }

    public static VcsConfigBuilder newBuilder(Map map) {
        return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(
        null,
        null,
                       (String)(map instanceof Map ? ((Map)map).getOrDefault("remote", "origin") : "origin"),
                       Boolean.parseBoolean(String.valueOf(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred","false") : "false"))));
    }

    public static String[] toStringArray(Object o) {
                if (o instanceof String[]) {
                  return (String[]) o;
                }
                if (o instanceof String) {
                  String s =  (String) o;
                  return s.split(",[ ]*");
                }
                else if (o instanceof List) {
                  List c = (List) o;
                  String[] result = new String[c.size()]; 
                  for (int i=0; i <= c.size(); i++) {
                    result[i] = String.valueOf(c.get(i));
                  }
                  return result;
                }
                return new String[0];
            
    }

}

==> option-annotations-2.1.0-sources.jar: io/dekorate/option/adapter/VcsConfigAdapter.java <==
package io.dekorate.option.adapter;

import io.dekorate.option.annotation.VcsOptions;
import io.dekorate.project.Project;
import io.dekorate.project.BuildInfo;
import io.dekorate.option.config.VcsConfig;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import io.dekorate.project.ScmInfo;
import java.lang.Boolean;
import java.util.Map;
import io.dekorate.option.config.VcsConfigBuilder;

public class VcsConfigAdapter {


    public static VcsConfig adapt(VcsOptions instance) {
        return newBuilder(instance).build();
    }

    public static VcsConfigBuilder newBuilder(VcsOptions instance) {
        return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(null,
                    null,
                    instance.remote(),
                    instance.httpsPreferred()));
    }

    public static VcsConfig adapt(Map map) {
        return new io.dekorate.option.config.VcsConfig(
        null,
        null,
                       (String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
                       (Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null));
    }

    public static VcsConfigBuilder newBuilder(Map map) {
        return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(
        null,
        null,
                       (String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
                       (Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null)));
    }

    public static String[] toStringArray(Object o) {
                if (o instanceof String[]) {
                  return (String[]) o;
                }
                if (o instanceof String) {
                  String s =  (String) o;
                  return s.split(",[ ]*");
                }
                else if (o instanceof List) {
                  List c = (List) o;
                  String[] result = new String[c.size()]; 
                  for (int i=0; i <= c.size(); i++) {
                    result[i] = String.valueOf(c.get(i));
                  }
                  return result;
                }
                return new String[0];
            
    }

}
